@@ -1,5 +1,5 @@
 package BalanceOfPower::Nation;
-$BalanceOfPower::Nation::VERSION = '0.300011';
+$BalanceOfPower::Nation::VERSION = '0.300012';
 use strict;
 use v5.10;
 
@@ -541,24 +541,6 @@ sub print_attributes
     return $out;
 }
 
-sub print
-{
-    my $self = shift;
-    my $out = "";
-    $out .= "Name: " . $self->name . "\n";
-    $out .= $self->print_attributes();
-    $out .= "Events:\n";
-    foreach my $year (sort keys %{$self->events})
-    {
-        $out .= "  $year:\n";
-        foreach my $e (@{$self->events->{$year}})
-        {
-            $out .= "    " . $e ."\n";
-        }
-    }
-    return $out;
-}
-
 sub dump
 {
     my $self = shift;
@@ -568,12 +550,6 @@ sub dump
                 join(";", $self->name, $self->code, $self->area, $self->export_quote, $self->government, $self->government_strength, $self->size, $self->internal_disorder, $self->production_for_domestic, $self->production_for_export, $self->prestige, $self->wealth, $self->debt, $self->rebel_provinces, $self->current_year, $self->army, $self->progress, $self->available_stocks) . "\n";
     $self->dump_events($io, " " . $indent);
 }
-#TODO finish this
-sub dump_resources
-{
-    my $self = shift;
-    my %data = shift;
-}
 
 sub load
 {
